#!/bin/bash

# Copyright (c) 2007 Chuck Houpt. All rights reserved.

set -eux

# Setup reasonable defaults when running outside XCode.
PROJECT_DIR=${PROJECT_DIR:-$PWD}
BUILD_DIR=${PROJECT_DIR}/vbuild
SDKROOT=${SDKROOT:-/Developer/SDKs/MacOSX10.6.sdk}

# Set up reasonable default when running outside mutibuild.sh
ARCH=${ARCH:-`arch`}
export MULTIBUILD_NCPU=${MULTIBUILD_NCPU:-`sysctl -n hw.ncpu`}

SOURCE_CACHE="$HOME/Library/Caches/net.habilis.source"

OPENSP_VERSION=OpenSP-1.5.2
OPENSP_URL=http://downloads.sourceforge.net/openjade/$OPENSP_VERSION.tar.gz
OPENSP_TARBALL=`basename $OPENSP_URL`

SRC_DIR="$BUILD_DIR"/$ARCH/$OPENSP_VERSION
PREFIX="$BUILD_DIR"/root
EXEC_PREFIX="$PREFIX"/$ARCH

# Make the arch flags part of CC/CXX, because gettext 1.2's old libtool doesn't
# include CFLAGS when linking dynamic libraries.
export CC="gcc -arch $ARCH"
export CXX="g++ -arch $ARCH"

#export CFLAGS="-Os -isysroot $SDKROOT"
#export CXXFLAGS="-Os -isysroot $SDKROOT"
#export LDFLAGS="-arch $ARCH -Wl,-syslibroot,$SDKROOT"

#PATH="$PATH:$PREFIX/bin"
#export CXXPP="-I$BUILD_DIR/gettext/include"
#export LDFLAGS="$LDFLAGS -L$BUILD_DIR/gettext/$ARCH/lib -lintl"

if [ -f "$EXEC_PREFIX"/bin/onsgmls ] ; then exit ; fi

if [ ! -r "$SOURCE_CACHE"/$OPENSP_TARBALL ]
then
	mkdir -p "$SOURCE_CACHE"
	pushd "$SOURCE_CACHE"
	curl -sfLO $OPENSP_URL
	popd
fi

if [ ! -d "$SRC_DIR" ]
then
	mkdir -p "$BUILD_DIR"/"$ARCH"
	pushd "$BUILD_DIR"/"$ARCH"
	tar xzf "$SOURCE_CACHE"/$OPENSP_TARBALL
	patch -p0 < "$PROJECT_DIR"/opensp-1.5.2.patch
	popd
fi

pushd "$SRC_DIR"


if [ ! -f Makefile ]
then
	#./configure --prefix="$PREFIX" --exec-prefix="$EXEC_PREFIX" --disable-doc-build --disable-static --disable-dependency-tracking --enable-nls
	./configure --prefix="$PREFIX" --exec-prefix="$EXEC_PREFIX" --enable-http --disable-doc-build --disable-static --disable-dependency-tracking
fi

make -j $MULTIBUILD_NCPU
make install

popd
